<?php
/**
*
*	Wp Lead Pages
*	(c) wpleadpages.com
*
*/
if(!defined('wlp_FILE')) {
	header('HTTP/1.0 403 Forbidden');
	exit;
}

register_activation_hook( wlp_FILE, 'wlp_plugin_activate' );
function wlp_plugin_activate() {
	require dirname(__FILE__) . '/wlp.predefinedtemplate.php';
}



/*
*	Load languages
*/
add_action('plugins_loaded', 'wlp_load_lang');
function wlp_load_lang() {
	load_plugin_textdomain( 'wpleadpages', false, wlp_SLUG . '/locales/' );
}



/*
*	Register assets ( js, css, font icons )
*/

function wlp_assets(){
	
	global $wlp;
	
	wp_enqueue_style('wlp-global', wlp_URL.'/assets/css/wlp.global.css', false, wlp_VERSION );

	// Stop loading assets from admin if not in allows content type
	if( is_admin() && !wlp_admin_enable() )
		return;
	
	wp_enqueue_script( 'wp-util' );
	
	$p = wlp_URL.'/assets/css/';
	
	$args = array( 
		'builder' => $p.'wlp.builder.css', 
		'params' => $p.'wlp.params.css'
	);
	
	$icon_sources = $wlp->get_icon_sources();
	if(  is_array( $icon_sources ) && count( $icon_sources ) > 0 ){
		$i = 1;
		foreach( $icon_sources as $icon_source ){
			$args['sys-icon-'.$i++] = $icon_source;
		}
	}
	
	$args = apply_filters( 'wlp-core-styles', $args );
	
	if( wpleadpages::is_live() ){
		$args['live'] = wlp_URL.'/includes/frontend/builder/assets/wlp.live.builder.css';
	}
	
	foreach( $args as $k => $v ){
		wp_enqueue_style('wlp-'.$k, $v, false, wlp_VERSION );
	}

	wp_register_script( 'wlp-builder-backend-js', wlp_URL.'/assets/js/wlp.builder.js', array('jquery','wp-util'), wlp_VERSION, true );
	wp_enqueue_script( 'wlp-builder-backend-js' );

	$p = '/assets/js/wlp.';
	$args = apply_filters( 'wlp-core-scripts', array( 
		'tools' => $p.'tools.js', 
		'views' => $p.'views.js', 
		'params' => $p.'params.js', 
		'jscolor' => $p.'vendors/jscolor.js', 
		'pikaday' => $p.'vendors/pikaday.js', 
		'freshslider' => $p.'vendors/freshslider.min.js') 
	);
	
	if( wpleadpages::is_live() ){
		$args['front-builder'] = '/includes/frontend/builder/assets/wlp.front.js';
		$args['front-detect'] = '/includes/frontend/builder/assets/wlp.detect.js';
	}
	
	foreach( $args as $k => $v ){
		wp_register_script( 'wlp-'.$k, wlp_URL.$v, null, wlp_VERSION, true );
		wp_enqueue_script( 'wlp-'.$k );
	}

	wp_enqueue_media();
	wp_enqueue_style( 'wp-pointer' );
	wp_enqueue_style('wlp-global1', wlp_URL.'/assets/css/wlp.custom.css', false, wlp_VERSION );
	
	if(!is_admin()){
	wp_enqueue_style('wlp-3', wlp_URL.'/includes/frontend/builder/assets/wlp.front.builder.css', false );
	}
	
}


/**
*	Register filter for menu title
*/


function wlp_filter_admin_menu_title( $menu_title ){

	$current = get_site_transient( 'update_plugins' );

    if ( ! isset( $current->response[ wlp_BASE ] ) )
		return $menu_title;

	return $menu_title . '&nbsp;<span class="update-plugins"><span class="plugin-count">1</span></span>';
}
add_filter( 'wlp_admin_menu_title', 'wlp_filter_admin_menu_title');

/*
*	Register settings page
*/

add_action('admin_menu', 'wlp_settings_menu');
function wlp_settings_menu() {
	
	$capability = apply_filters( 'access_origincomposer_capability', 'access_origincomposer' );
	$icon = wlp_URL.'/assets/images/logo100.png';
	$menu_title = apply_filters( 'wlp_admin_menu_title', __( 'Wp Lead Pages' , 'wpleadpages' ) );

	remove_submenu_page( 'wpleadpages', 'wpleadpages' );
   
	add_submenu_page(
		'options-general.php',
		esc_html__('Wp Lead Pages', 'wpleadpages'),
		esc_html__('Wp Lead Pages', 'wpleadpages'),
		'manage_options',
		'wlp-sections-manager',
		'wlp_sections_manager'
	);
	
	add_submenu_page(
		'options-general.php',
		esc_html__('Lead subscriber', 'wpleadpages'),
		esc_html__('Lead subscriber', 'wpleadpages'),
		'manage_options',
		'wlp-lead-subscriber',
		'wlp_lead_subscriber'
	);
}



add_action( 'admin_head', 'wlp_admin_header' );
add_action( 'admin_footer', 'wlp_admin_footer' );

 

/*
*	Header init
*/



function wlp_admin_header(){

	if( is_admin() && !wlp_admin_enable() )
		return;
	
	$wlp = wpleadpages::globe();
	
?>
<script type="text/javascript">

	var site_url = '<?php echo site_url(); ?>',
		plugin_url = '<?php echo wlp_URL; ?>',
		shortcode_tags = '<?php

			global $shortcode_tags;

			$arrg = array();
			$maps = $wlp->get_maps();

			foreach( $maps as $key => $val ){
				array_push( $arrg, $key );
			}

			foreach( $shortcode_tags as $key => $val ){
				if( !in_array( $key, $arrg ) )
					array_push( $arrg, $key );
			}

			echo implode( '|', $arrg );
		
		?>',
		<?php 
			
			if( isset( $_GET['id'] ) )
				echo 'wlp_post_ID = "'.$_GET['id'].'",'; 
		?>
		wlp_version = '<?php echo wlp_VERSION; ?>',
		wlp_ajax_url = "<?php echo site_url('/wp-admin/admin-ajax.php'); ?>",
		wlp_profiles = <?php echo $wlp->get_profiles_db( false ); ?>,
		wlp_profiles_external = <?php echo json_encode( (object)$wlp->get_profile_sections() ); ?>,
		wlp_ajax_nonce = '<?php echo wp_create_nonce( "wlp-nonce" ); ?>';

		<?php 
			if( get_option('wlp_tkl_cc') ){
				echo get_option('wlp_tkl_cc', true);
			}
		?>
		
</script>
<?php
}

/*
*	Load builder template at footer
*/

function wlp_admin_footer(){

	if( is_admin() && !wlp_admin_enable() )
		return;

	do_action('wlp_before_footer');
	
	require_once wlp_PATH.'/includes/wlp.js_languages.php';
	require_once wlp_PATH.'/includes/wlp.nocache_templates.php';
	
	if( wpleadpages::is_live() ){
		
		require_once wlp_PATH.'/includes/frontend/builder/wlp.templates.php';
	
	}
	
	do_action('wlp_after_footer');
	
}

/*
*	Include admin pages' file
*/


function wlp_main_page() {
	if( wpleadpages::is_live() )
		require_once wlp_PATH.KDS.'includes'.KDS.'wlp.live.builder.php';
	else require_once wlp_PATH.KDS.'includes'.KDS.'wlp.settings.php';
}

add_action( 'edit_form_after_editor', 'myprefix_edit_form_after_editor' );
function myprefix_edit_form_after_editor() {
	global $post;
	$enqnue = get_post_meta($post->ID, '__wp_page_template_', true);
	if($enqnue == true){
		wp_register_script( 'wlp-builder-admin-js', wlp_URL.'/assets/js/wlp.admin.js', array('jquery'), wlp_VERSION, true );
		wp_enqueue_script( 'wlp-builder-admin-js' );
	}
}

function wlp_sections_manager() {
	//add_action('admin_enqueue_scripts', 'wlp_assets', 1 );
	wlp_assets();
	require_once wlp_PATH.KDS.'includes'.KDS.'wlp.sections.php';
}

function wlp_lead_subscriber() {
	
	wp_enqueue_style('wlp.subscriber',  wlp_URL.'/assets/css/wlp.subscriber.css');
	
	require_once wlp_PATH.KDS.'includes'.KDS.'wlp.lead.subscriber.php';
}


add_action( 'wp_ajax_wlp_save_subscriber_setting', 'wlp_save_subscriber_setting' );
add_action( 'wp_ajax_nopriv_wlp_save_subscriber_setting', 'wlp_save_subscriber_setting' );
function wlp_save_subscriber_setting(){
	//print_r($_POST);
	
	$data = get_option('wlp_subscriber_settings');
	
	if(empty($_POST['responder'])){
		echo json_encode(array( 'error' => 'Error occur may be something wrong.'));
		return;
	}
	
	$data[$_POST['responder']] = $_POST['apikey'];
	
	if(empty($_POST['apikey'])){
		update_option('wlp_subscriber_settings', $data);
		die();
	}
	
	if(!empty($data[$_POST['responder']]['api_key'])){
		$objlist = new wlp_subscriber();
		$list = $objlist->switch_responder($_POST['apikey'], 'getList', $_POST['responder']);
		$res = $_POST['responder'];
		if( $res!='Aweber'){ 
			update_option('wlp_subscriber_settings', $data);
		}
		echo json_encode(array('success'=>true));
	}else{
		echo json_encode(array('error'=>'An error occurred while getting your list.'));
	} 
	
	die();
}

add_action( 'wp_ajax_wlp_get_subscriber_setting', 'wlp_get_subscriber_setting' );
add_action( 'wp_ajax_nopriv_wlp_get_subscriber_setting', 'wlp_get_subscriber_setting' );
function wlp_get_subscriber_setting(){	
	if(empty($_POST['responder'])){
		echo json_encode(array( 'error' => 'Error occur may be something wrong.'));
		return;
	}
	
	$data = get_option('wlp_subscriber_settings');
	
	if(empty($data[$_POST['responder']])){
		echo json_encode(array('error'=>'please check settings.'));
		die();
	}
	
	$api = $data[$_POST['responder']];
	
	$objlist = new wlp_subscriber();
	$list = $objlist->switch_responder($api, 'getList', $_POST['responder']);
	
	echo json_encode($list);
	
	die();
}

//add_filter('wlp_css_custom', 'wlp_css_custom_function', 10, 1);
function wlp_css_custom_function( $css ){
	$ex = explode( '|', $css );
	
	global $wlp_css_;
	
	$wlp_css_ .= ".".$ex[0]."{".$ex[1]."}";
	
	if(isset($ex[0])) return $ex[0];
	
	//return 'rahul';
}